==> nim_fluttify-0.1.2.tar.gz: example/lib/src/history/history.screen.dart <==
import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:flutter/material.dart';
import 'package:nim_fluttify/nim_fluttify.dart';
import 'package:nim_fluttify_example/src/mixins.dart';

class HistoryScreen extends StatefulWidget {
  @override
  _HistoryScreenState createState() => _HistoryScreenState();
}

class _HistoryScreenState extends State<HistoryScreen> with AccountTokenMixin {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('历史记录列表')),
      body: PreferredFutureBuilder<List<MessageVM>>(
        future: _fetchHistory(),
        builder: (data) {
          return ListView.builder(
            itemCount: data.length,
            itemBuilder: (context, index) {
              return _MessageItem(data[index]);
            },
          );
        },
      ),
    );
  }

  Future<List<MessageVM>> _fetchHistory() async {
    final messageList = await Nim.instance
        .fetchMessageList(peerAccount, sessionType: SessionType.p2p);
    return [for (final friend in messageList) await MessageVM.data(friend)];
  }
}

class MessageVM {
  static Future<MessageVM> data(Message data) async {
    return MessageVM()..senderAccount = await data.senderAccount;
  }

  String senderAccount;
}

class _MessageItem extends StatelessWidget {
  const _MessageItem(this.vm, {Key key}) : super(key: key);

  final MessageVM vm;

  @override
  Widget build(BuildContext context) {
    return Card(
      child: DecoratedColumn(
        padding: EdgeInsets.all(kSpaceNormal),
        children: <Widget>[
          Text('好友账号: ${vm.senderAccount}'),
        ],
      ),
    );
  }
}

==> nim_fluttify-0.1.5.tar.gz: example/lib/src/history/history.screen.dart <==
import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:flutter/material.dart';
import 'package:nim_fluttify/nim_fluttify.dart';
import 'package:nim_fluttify_example/src/mixins.dart';

class HistoryScreen extends StatefulWidget {
  @override
  _HistoryScreenState createState() => _HistoryScreenState();
}

class _HistoryScreenState extends State<HistoryScreen> with AccountTokenMixin {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('历史记录列表')),
      body: PreferredFutureBuilder<List<MessageVM>>(
        future: _fetchHistory(),
        builder: (data) {
          return ListView.builder(
            itemCount: data.length,
            itemBuilder: (context, index) {
              return _MessageItem(data[index]);
            },
          );
        },
      ),
    );
  }

  Future<List<MessageVM>> _fetchHistory() async {
    final messageList = await Nim.instance
        .fetchMessageList(peerAccount, sessionType: SessionType.p2p);
    return [for (final friend in messageList) await MessageVM.data(friend)];
  }
}

class MessageVM {
  static Future<MessageVM> data(Message data) async {
    return MessageVM()
      ..sessionId = await data.sessionId
      ..senderAccount = await data.senderAccount
      ..senderNickname = await data.senderNickname
      ..time = await data.time;
  }

  String sessionId;
  String senderAccount;
  String senderNickname;
  DateTime time;
}

class _MessageItem extends StatelessWidget {
  const _MessageItem(this.vm, {Key key}) : super(key: key);

  final MessageVM vm;

  @override
  Widget build(BuildContext context) {
    return Card(
      child: DecoratedColumn(
        padding: EdgeInsets.all(kSpaceNormal),
        children: <Widget>[
          Text('会话id: ${vm.sessionId}'),
          Text('发送方账号: ${vm.senderAccount}'),
          Text('发送方昵称: ${vm.senderNickname}'),
          Text('发送时间: ${vm.time}'),
        ],
      ),
    );
  }
}
